@@ -1,4 +1,4 @@
-// $Id: AppData.h,v 1.125 1998/11/27 19:46:26 zeller Exp $ -*- C++ -*-
+// $Id: AppData.h,v 1.125.4.1 1998/12/06 12:59:15 zeller Exp $ -*- C++ -*-
 // DDD application data
 
 // Copyright (C) 1996-1998 Technische Universitaet Braunschweig, Germany.
@@ -162,6 +162,10 @@
 #define XtCUseTTYCommand         "UseTTYCommand"
 #define XtNquestionTimeout       "questionTimeout"
 #define XtCQuestionTimeout       "QuestionTimeout"
+#define XtNpositionTimeout       "positionTimeout"
+#define XtCPositionTimeout       "PositionTimeout"
+#define XtNdisplayTimeout        "displayTimeout"
+#define XtCDisplayTimeout        "DisplayTimeout"
 #define XtNsynchronousDebugger   "synchronousDebugger"
 #define XtCSynchronousDebugger   "SynchronousDebugger"
 #define XtNterminateOnEOF        "terminateOnEOF"
@@ -462,6 +466,8 @@ struct AppData {
     String    term_type;
     Boolean   use_tty_command;
     int       question_timeout;
+    int       position_timeout;
+    int       display_timeout;
     Boolean   synchronous_gdb;
     Boolean   terminate_on_eof;
     Boolean   poll_child_status;
