@@ -1,7 +1,7 @@
-// $Id: Assoc.h,v 1.13 1998/05/18 15:14:25 zeller Exp $
+// $Id: Assoc.h,v 1.16 1998/11/24 16:42:53 zeller Exp $
 // Associative array
 
-// Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
+// Copyright (C) 1995-1998 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
 // This file is part of the ICE Library.
@@ -36,6 +36,8 @@
 #include "bool.h"
 #include "assert.h"
 
+#include <stdlib.h>		// abort()
+
 template<class K, class V> class AssocMark;
 template<class K, class V> class _Assoc;
 template<class K, class V> class Assoc;
@@ -187,7 +189,7 @@ public:
     }
 
     // Assignment
-    _Assoc<K, V> operator = (const _Assoc<K,V>& m)
+    _Assoc<K, V>& operator = (const _Assoc<K,V>& m)
     {
 	if (this != &m)
 	{
@@ -198,6 +200,7 @@ public:
 	    for (AssocRec<K,V> *e = m.entries; e != 0; e = e->next)
 		(*this)[e->key] = e->value;
 	}
+
 	return *this;
     }
 };
@@ -308,6 +311,26 @@ public:
 
 	entries = e;
     }
+
+    // Constructor
+    Assoc()
+	: _Assoc<K, V>() 
+    {}
+
+    // Destructor
+    ~Assoc() {}
+
+    // Copy
+    Assoc(const Assoc<K, V>& m)
+	: _Assoc<K, V>(m)
+    {}
+
+    // Assignment
+    Assoc<K, V>& operator = (const Assoc<K, V>& m)
+    {
+	_Assoc<K, V>::operator =(m);
+	return *this;
+    }
 };
 
 #endif // _ICE_Assoc_h
