@@ -1,4 +1,4 @@
-// $Id: DataDisp.h,v 1.88 1998/06/11 16:13:47 zeller Exp $
+// $Id: DataDisp.h,v 1.109 1998/11/30 09:38:04 zeller Exp $
 // Data Display
 
 // Copyright (C) 1995-1997 Technische Universitaet Braunschweig, Germany.
@@ -52,27 +52,24 @@
 // Motif includes
 #include <Xm/Xm.h>
 
-// Misc includes
-#include "strclass.h"
-#include "MakeMenu.h"
-#include "HelpCB.h"
-#include "ExitCB.h"
-#include "events.h"
-#include "VSEFlags.h"
-#include "VSLLib.h"
-#include "Delay.h"
-#include "IntArray.h"
-#include "MString.h"
-#include "DispNode.h"
-#include "string-fun.h"
-
 // DDD includes
 #include "ArgField.h"
+#include "BoxSize.h"
 #include "Command.h"
+#include "Delay.h"
+#include "ExitCB.h"
 #include "GDBAgent.h"
 #include "GraphEdit.h"
-#include "DispBox.h"
+#include "HelpCB.h"
+#include "IntArray.h"
+#include "MString.h"
+#include "MakeMenu.h"
 #include "StringA.h"
+#include "VSEFlags.h"
+#include "VSLLib.h"
+#include "events.h"
+#include "strclass.h"
+#include "string-fun.h"
 
 
 //-----------------------------------------------------------------------------
@@ -87,10 +84,16 @@ enum DeferMode {
 
 class NewDisplayInfo;
 class DispGraph;
+class DispNode;
+class DispBox;
+class DispValue;
+class RegionGraphNode;
 
 //-----------------------------------------------------------------------------
 class DataDisp {
 
+    friend class DataDispCount;
+
     //-----------------------------------------------------------------------
     // Callbacks
     //-----------------------------------------------------------------------
@@ -101,11 +104,11 @@ class DataDisp {
     //-----------------------------------------------------------------------
     static void dereferenceCB           (Widget, XtPointer, XtPointer);
     static void dereferenceArgCB        (Widget, XtPointer, XtPointer);
+    static void dereferenceInPlaceCB    (Widget, XtPointer, XtPointer);
     static void toggleDetailCB          (Widget, XtPointer, XtPointer);
     static void toggleRotateCB          (Widget, XtPointer, XtPointer);
     static void toggleDisableCB         (Widget, XtPointer, XtPointer);
     static void rotateCB                (Widget, XtPointer, XtPointer);
-    static void rotateAllCB             (Widget, XtPointer, XtPointer);
     static void newCB                   (Widget, XtPointer, XtPointer);
     static void enableCB                (Widget, XtPointer, XtPointer);
     static void disableCB               (Widget, XtPointer, XtPointer);
@@ -114,9 +117,14 @@ class DataDisp {
     static void hideDetailCB            (Widget, XtPointer, XtPointer);
     static void dependentCB             (Widget, XtPointer, XtPointer);
     static void displayArgCB            (Widget, XtPointer, XtPointer);
+    static void plotArgCB               (Widget, XtPointer, XtPointer);
+    static void plotHistoryCB           (Widget, XtPointer, XtPointer);
     static void setCB                   (Widget, XtPointer, XtPointer);
     static void shortcutCB              (Widget, XtPointer, XtPointer);
     static void deleteArgCB		(Widget, XtPointer, XtPointer);
+    static void clusterSelectedCB       (Widget, XtPointer, XtPointer);
+    static void unclusterSelectedCB     (Widget, XtPointer, XtPointer);
+    static void toggleClusterSelectedCB (Widget, XtPointer, XtPointer);
 
     //-----------------------------------------------------------------------
     // Popup menu callbacks
@@ -124,7 +132,6 @@ class DataDisp {
     static void popup_new_argCB         (Widget, XtPointer, XtPointer);
     static void popup_newCB             (Widget, XtPointer, XtPointer);
     static void new_displayDCB          (Widget, XtPointer, XtPointer);
-    static void setDCB                  (Widget, XtPointer, XtPointer);
 
     //-----------------------------------------------------------------------
     // Callbacks of the display editor
@@ -184,17 +191,18 @@ class DataDisp {
     static void close_data_window();
 
     static DispNode *new_data_node(const string& name, const string& scope,
-				   const string& answer);
+				   const string& answer, bool plotted);
     static DispNode *new_user_node(const string& name, const string& scope,
-				   const string& answer);
+				   const string& answer, bool plotted);
     static DispNode *new_deferred_node(const string& expr, const string& scope,
 				       const BoxPoint& pos,
-				       const string& depends_on);
+				       const string& depends_on,
+				       bool clustered, bool plotted);
 
     static int getDispNrAtPoint(BoxPoint point);
 
     static string numbers(IntArray& a);
-    static bool all_display_numbers(IntArray& numbers);
+    static bool all_data_displays(IntArray& numbers);
 
     static void show(Widget dialog, int depth, int more);
 
@@ -203,6 +211,21 @@ class DataDisp {
 
     static void toggle_rotate(DispValue *dv, bool all = false);
 
+    static void select_node(DispNode *dn, int src = 0);
+
+    // Setting values
+    static void setDCB (Widget, XtPointer, XtPointer);
+    static void DeleteSetInfoCB(Widget, XtPointer client_data, XtPointer);
+    static void SetDone(const string& answer, void *qu_data);
+
+    // Builtin user displays
+    static bool is_builtin_user_command(const string& cmd);
+    static string builtin_user_command(const string& cmd, DispNode *dn = 0);
+    static void refresh_builtin_user_displays();
+
+    // DispNode properties
+    static bool needs_refresh(DispNode *dn);
+    static bool selected(DispNode *dn);
 
     //-----------------------------------------------------------------------
     // Actions
@@ -231,9 +254,11 @@ class DataDisp {
     static MMDesc shortcut_popup1[];
     static MMDesc shortcut_popup2[];
     static MMDesc display_area[];
+    static MMDesc plot_menu[];
     static MMDesc detail_menu[];
     static MMDesc shortcut_menu[];
     static MMDesc rotate_menu[];
+    static MMDesc delete_menu[];
 
     static const int shortcut_items;
 
@@ -259,12 +284,16 @@ public:
     // If DEPENDS_ON is set, the new display is made dependent on
     // DEPENDS_ON (a display number or name).
     // If DEFERRED is set, defer creation until SCOPE is reached.
+    // If CLUSTERED is set, cluster display.
+    // If PLOTTED is set, plot display.
     // If ORIGIN is set, the last origin is set to ORIGIN.
     static void new_displaySQ(string display_expression,
 			      string scope,
 			      BoxPoint *pos = 0,
 			      string depends_on = "",
 			      DeferMode deferred = DeferAlways,
+			      bool clustered = false,
+			      bool plotted = false,
 			      Widget origin = 0,
 			      bool verbose = true,
 			      bool prompt = true);
@@ -290,9 +319,11 @@ public:
 				 bool prompt = true);
 
     // Same, but return the appropriate command
-    static string new_display_cmd(string display_expression,
+    static string new_display_cmd(const string& display_expression,
 				  BoxPoint *pos = 0,
-				  string depends_on = "");
+				  const string& depends_on = "",
+				  bool clustered = false,
+				  bool plotted = false);
 
     static string refresh_display_cmd();
     static string disable_display_cmd(IntArray& display_nrs);
@@ -304,10 +335,13 @@ public:
     static void new_display(string display_expression,
 			    BoxPoint *pos = 0,
 			    string depends_on = "",
+			    bool clustered = false,
+			    bool plotted = false,
 			    Widget origin = 0)
     {
-	gdb_command(new_display_cmd(display_expression, pos, depends_on), 
-		    origin);
+	string c = new_display_cmd(display_expression, pos, 
+				   depends_on, clustered, plotted);
+	gdb_command(c, origin);
     }
 
     static void refresh_display(Widget origin = 0)
@@ -416,6 +450,7 @@ private:
     static int next_ddd_display_number;
     static int next_gdb_display_number;
     static bool detect_aliases;
+    static bool cluster_displays;
     static bool arg_needs_update;
 
     static Widget graph_popup_w;
@@ -464,9 +499,20 @@ private:
 			  const StringArray& scopes,
 			  int target_frame);
 
+    static void get_node_state(ostream& os, DispNode *dn,
+			       bool include_position);
+
     // Reset done
     static void reset_done(const string& answer, void *data);
 
+    // Clustering stuff
+    static void insert_data_node(DispNode *dn, int depend_nr,
+				 bool clustered, bool plotted);
+    static int new_cluster();
+    static int current_cluster();
+
+    static DispValue *update_hook(string& value);
+
 public:
     static Widget graph_edit;
     static Widget graph_cmd_w;
@@ -475,12 +521,13 @@ public:
     static bool bump_displays;
 
     // Constructor
-    DataDisp(Widget parent);
+    DataDisp(Widget parent, Widget& data_buttons_w);
 
     void create_shells();
 
     static int count_data_displays();
     static void get_all_display_numbers(IntArray& numbers);
+    static void get_all_clusters(IntArray& numbers);
     static void refresh_graph_edit (bool silent = false);
     static Widget graph_form() { return graph_form_w; }
 
@@ -511,6 +558,9 @@ public:
     // Set whether aliases are to be detected
     static void set_detect_aliases(bool value);
 
+    // Set whether displays are to be clustered
+    static void set_cluster_displays(bool value);
+
     // True iff we have some selection
     static bool have_selection();
 
@@ -535,14 +585,29 @@ public:
     // Returns 0 if W is no shortcut menu item.
     static MString shortcut_help(Widget w);
 
+    // Select a specific value.  Plotter uses this.
+    static void select(DispValue *dv);
+
     // Reset all
     static void reset();
 
     // True if the selection was lost
     static void SelectionLostCB(Widget = 0, XtPointer = 0, XtPointer = 0);
 
-    // Get number of display NAME
+    // Get number(s) of display NAME
     static int display_number(const string& name, bool verbose = false);
+    static void get_display_numbers(const string& name, IntArray& numbers);
+
+    // Refresh titles after change in APP_DATA
+    static void refresh_titles();
+
+    // Update and activate displays manually (from undo)
+    static void update_displays(const StringArray& names, 
+				const StringArray& values,
+				const StringArray& addrs);
+
+    // Restore sane state
+    static void make_sane();
 };
 
 inline bool DataDisp::get_selection(ostream& os, bool include_position)
