@@ -1,4 +1,4 @@
-// $Id: DispNode.h,v 1.22 1998/04/01 13:24:23 zeller Exp $
+// $Id: DispNode.h,v 1.41 1998/11/17 10:51:16 zeller Exp $
 // Store information about a single display espression
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -44,10 +44,9 @@
 #include "GraphNode.h"
 #include "HandlerL.h"
 #include "BoxGraphN.h"
-
-// DDD includes
 #include "DispValue.h"
-#include "DispBox.h"
+
+class DispBox;
 
 // Event types
 const unsigned DispNode_Disabled   = 0;
@@ -59,35 +58,41 @@ const unsigned DispNode_NTypes  = DispNode_Disabled + 1;
 //-----------------------------------------------------------------------------
 
 // Return true iff S is a user command display (`status display')
-bool is_user_command(const string& s);
+inline bool is_user_command(const string& s)
+{
+    return s.length() >= 2 && s[0] == '`' && s[s.length() - 1] == '`';
+}
 
 // Return user command from S
 string user_command(const string& s);
 
-
 //-----------------------------------------------------------------------------
 // The DispNode class
 //-----------------------------------------------------------------------------
 
-class DispNode 
-{
+class DispNode: public BoxGraphNode {
+public:
+    DECLARE_TYPE_INFO
+
 private:
     int           mydisp_nr;	      // Display number
     string        myname;	      // Display expression
     string        myaddr;	      // Location of expression
     string        myscope;	      // Program location where created
     string        mydepends_on;	      // Display we depend upon (when deferred)
-    bool          myenabled;	      // Flag: is display enabled?
     bool          myactive;	      // Flag: is display active (in scope)?
     bool          saved_node_hidden;  // Saved `hidden' flag of node
     bool          mydeferred;	      // Flag: is display deferred?
-    BoxGraphNode* mynodeptr;	      // Associated graph node 
+    int           myclustered;	      // Flag: is display clustered?
+    bool          myplotted;	      // Flag: is display plotted?
+    bool          myconstant;	      // Flag: is display constant?
     DispValue*    disp_value;	      // Associated value
     DispValue*    myselected_value;   // Selected value within DISP_VALUE
     DispBox*      disp_box;	      // Associated box within DISP_VALUE
     int           mylast_change;      // Last value or address change
+    int           mylast_refresh;     // Last refresh
 
-    static int change_tics;           // Shared change counter
+    static int tics;		      // Shared change and refresh counter
 
 public:
     int           alias_of;	      // Alias of another display
@@ -95,16 +100,15 @@ public:
 protected:
     static HandlerList handlers;
     static class TagBox *findTagBox(const Box *box, DispValue *dv);
+    
+    virtual string str() const { return myname; }
+
+    DispNode(const DispNode& node);
+
+    virtual void refresh_plot_state() const;
 
 private:
-    DispNode(const DispNode&)
-	: mydisp_nr(0), myname(), myaddr(), myscope(), mydepends_on(),
-	  myenabled(false), myactive(false), saved_node_hidden(false),
-	  mydeferred(false), mynodeptr(0), disp_value(0), 
-	  myselected_value(0), disp_box(0), mylast_change(0), alias_of(0)
-    {
-	assert(0);
-    }
+    // Prohibit assignment
     DispNode& operator = (const DispNode&) { assert(0); return *this; }
 
 public:
@@ -112,12 +116,19 @@ public:
     // SCOPE (a function name or "") with a value of VALUE.
     DispNode(int disp_nr,
 	     const string& name,
-	     const string& scope = "",
-	     const string& value = "");
+	     const string& scope,
+	     const string& value,
+	     bool plotted);
 
     // Destructor
     ~DispNode();
 
+    // Duplication
+    GraphNode *dup() const
+    {
+	return new DispNode(*this);
+    }
+
     // Resources
     int disp_nr()  const             { return mydisp_nr; }
     const string& name() const       { return myname; }
@@ -134,13 +145,23 @@ public:
 	return mydepends_on;
     }
 
-    bool enabled()  const   { return myenabled; }
-    bool disabled() const   { return !myenabled; }
-    bool active() const     { return myactive; }
-    bool deferred() const   { return mydeferred; }
-    bool& deferred()        { return mydeferred; }
+    bool enabled()  const { return value() != 0 && value()->enabled(); }
+    bool disabled() const { return !enabled(); }
+    bool active() const   { return myactive; }
+    bool deferred() const { return mydeferred; }
+    bool& deferred()      { return mydeferred; }
+    int clustered() const { return myclustered; }
+    bool plotted() const  { return myplotted; }
+    bool& plotted()       { return myplotted; }
+    bool constant() const { return myconstant; }
+    bool& constant()      { return myconstant; }
 
-    int last_change() const { return mylast_change; }
+    int last_change() const  { return mylast_change; }
+    int last_refresh() const { return mylast_refresh; }
+
+    // These can be used to force updates
+    void set_last_change(int value = 0)  { mylast_change  = value; }
+    void set_last_refresh(int value = 0) { mylast_refresh = value; }
 
     bool is_user_command() const { return ::is_user_command(name()); }
     string user_command() const  { return ::user_command(name()); }
@@ -148,13 +169,8 @@ public:
     // Return `true' if this expression can be aliased
     bool alias_ok() const;
 
-    BoxGraphNode* nodeptr() const { return mynodeptr; }
-    const Box*    box()     const { return mynodeptr->box(); }
-    DispValue*    value()   const { return disp_value; }
-    DispValue*    selected_value() const { return myselected_value; }
-
-    bool& selected()                    { return mynodeptr->selected(); }
-    void moveTo(const BoxPoint& newPos) { mynodeptr->moveTo(newPos); }
+    DispValue* value()          const { return disp_value; }
+    DispValue* selected_value() const { return myselected_value; }
 
     // Handlers
     static void addHandler (unsigned    type,
@@ -167,18 +183,21 @@ public:
 
 
 
-    // Update with NEW_VALUE;  return false if value is unchanged
+    // Update with NEW_VALUE; return false if value is unchanged
     bool update (string& new_value);
 
     // Update address with NEW_ADDR
     void set_addr(const string& new_addr);
 
     // Re-create the box from old DISP_VALUE
-    void refresh ();
+    void refresh();
 
     // Highlights the box related to the display value DV
     void select (DispValue *dv = 0);
 
+    // Copy selection state from SRC
+    void copy_selection_state(const DispNode& src);
+
     // Disable and enable manually
     void disable();
     void enable();
@@ -186,7 +205,28 @@ public:
     // Show and hide manually
     void make_active();
     void make_inactive();
+
+    // Cluster display into TARGET
+    void cluster(int target);
+    inline void uncluster() { cluster(0); }
+
+    // Toggle titles.  Return true iff changed.
+    bool set_title(bool set);
+
+    // Print plots to FILENAME
+    void print_plots(const string& filename, 
+		     const GraphGC& gc = GraphGC()) const;
 };
 
+// Clustering stuff
+
+// The command to use for clusters
+#define CLUSTER_COMMAND "displays"
+
+inline bool is_cluster(DispNode *dn)
+{
+    return dn->is_user_command() && dn->user_command() == CLUSTER_COMMAND;
+}
+
 #endif // _DDD_DispNode_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
