@@ -1,4 +1,4 @@
-// $Id: Graph.h,v 1.16 1998/03/25 12:43:17 zeller Exp $
+// $Id: Graph.h,v 1.18 1998/10/05 12:21:05 zeller Exp $
 // Graph Class
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -50,6 +50,13 @@ private:
 
     Graph& operator = (const Graph&) { assert(0); return *this; }
 
+    void begin_color(ostream& os, const PrintGC& gc,
+		     unsigned short red,
+		     unsigned short green,
+		     unsigned short blue) const;
+    void end_color(ostream& os, const PrintGC& gc) const;
+
+
 protected:
     void addNodes(GraphNode* nodes);
     void addEdges(GraphEdge* edges);
@@ -181,11 +188,13 @@ public:
     void _print(ostream& os, const GraphGC& gc) const;
     void _printHeader(ostream& os, const GraphGC& gc) const
     {
-	Box::_printHeader(os, region(gc), *gc.printGC);
+	Box::_printHeader(os, region(gc, gc.printSelectedNodesOnly), 
+			  *gc.printGC);
     }
     void _printTrailer(ostream& os, const GraphGC& gc) const
     {
-	Box::_printTrailer(os, region(gc), *gc.printGC);
+	Box::_printTrailer(os, region(gc, gc.printSelectedNodesOnly),
+			   *gc.printGC);
     }
 
     // Custom printing function
@@ -197,7 +206,7 @@ public:
     }
 
     // Total Region
-    BoxRegion region(const GraphGC& gc) const;
+    BoxRegion region(const GraphGC& gc, bool selected_only = false) const;
 
     // Representation invariant
     virtual bool OK() const;
