@@ -1,4 +1,4 @@
-// $Id: GraphEdge.h,v 1.16 1998/03/25 12:43:18 zeller Exp $
+// $Id: GraphEdge.h,v 1.17 1998/08/02 14:36:49 zeller Exp $
 // GraphEdge Class
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -133,7 +133,10 @@ public:
     // Printing
     virtual void _print(ostream& os, const GraphGC& gc) const;
 
-    // representation invariant
+    // Region occupied by edge - if none, BoxRegion()
+    virtual BoxRegion region(const GraphGC&) const { return BoxRegion(); }
+
+    // Representation invariant
     virtual bool OK() const;
 };
 
