@@ -1,4 +1,4 @@
-// $Id: GraphEdit.h,v 1.20 1998/05/04 17:24:48 zeller Exp $
+// $Id: GraphEdit.h,v 1.27 1998/11/30 08:59:12 zeller Exp $
 // GraphEdit Widget -- public interface
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -33,8 +33,12 @@
 #pragma interface
 #endif
 
-#include "Graph.h"
 #include <X11/Intrinsic.h>
+#include "BoxPoint.h"
+
+class Graph;
+class GraphGC;
+class GraphNode;
 
 
 // define any special resource names here that are not in <X11/StringDefs.h>
@@ -45,7 +49,9 @@
 #define XtNmoveDelta                "moveDelta"
 #define XtNrubberEdges              "rubberEdges"
 #define XtNrubberArrows             "rubberArrows"
+#define XtNrubberAnnotations        "rubberAnnotations"
 #define XtNshowHints                "showHints"
+#define XtNshowAnnotations          "showAnnotations"
 #define XtNhintSize                 "hintSize"
 #define XtNopaqueMove               "opaqueMove"
 #define XtNautoRaise                "autoRaise"
@@ -85,9 +91,12 @@
 #define XtNoutlineColor             "outlineColor"
 #define XtNgridColor                "gridColor"
 #define XtNselectColor              "selectColor"
+#define XtNnodePrintColor           "nodePrintColor"
+#define XtNedgePrintColor           "edgePrintColor"
 #define XtNselfEdgeDiameter         "selfEdgeDiameter"
 #define XtNselfEdgePosition         "selfEdgePosition"
 #define XtNselfEdgeDirection        "selfEdgeDirection"
+#define XtNdashedLines              "dashedLines"
 
 
 
@@ -97,7 +106,9 @@
 #define XtCMoveDelta         "MoveDelta"
 #define XtCRubberEdges       "RubberEdges"
 #define XtCRubberArrows      "RubberArrows"
+#define XtCRubberAnnotations "RubberAnnotations"
 #define XtCShowHints         "ShowHints"
+#define XtCShowAnnotations   "ShowAnnotations"
 #define XtCHintSize          "HintSize"
 #define XtCOpaqueMove        "OpaqueMove"
 #define XtCAutoRaise         "AutoRaise"
@@ -116,6 +127,7 @@
 #define XtCSelfEdgeDiameter  "SelfEdgeDiameter"
 #define XtCSelfEdgePosition  "SelfEdgePosition"
 #define XtCSelfEdgeDirection "SelfEdgeDirection"
+#define XtCDashedLines       "DashedLines"
 
 
 // Representation types
@@ -179,21 +191,23 @@ struct GraphEditPositionChangedInfo {
 struct GraphEditPreSelectionInfo {
     Graph     *graph;		// Graph this node is in
     GraphNode *node;		// Selected node
+    XEvent    *event;		// Event
     Boolean   double_click;	// Double-click?
     Boolean   doit;		// Flag: do default action?
 
     GraphEditPreSelectionInfo():
-        graph(0), node(0), double_click(False), doit(True)
+        graph(0), node(0), event(0), double_click(False), doit(True)
     {}
     GraphEditPreSelectionInfo(const GraphEditPreSelectionInfo& info):
-        graph(info.graph), node(info.node), double_click(info.double_click),
-	doit(info.doit)
+        graph(info.graph), node(info.node), event(info.event),
+	double_click(info.double_click), doit(info.doit)
     {}
     GraphEditPreSelectionInfo& 
         operator = (const GraphEditPreSelectionInfo& info)
     {
 	graph        = info.graph;
 	node         = info.node;
+	event        = info.event;
 	double_click = info.double_click;
 	doit         = info.doit;
 	return *this;
