@@ -1,5 +1,5 @@
-// $Id: HatBox.h,v 1.12 1998/03/25 12:43:25 zeller Exp $
-// Deklaration Klasse HatBox
+// $Id: HatBox.h,v 1.14 1998/11/23 15:00:21 zeller Exp $
+// A box with a single child
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
@@ -34,9 +34,8 @@
 #endif
 
 
-// Eine HatBox stuelpt sich wie ein Hut ueber eine andere Box, um
-// bestimmte Eigenschaften zu veraendern (insbesondere Groesse,
-// Ausdehnung usw.).
+// A HatBox envelops a child (like a hat) to change specific
+// properties such as size or extent.
 
 #include "Box.h"
 #include "Widget.h"
@@ -96,7 +95,7 @@ public:
 
     void _print(ostream& os, 
 		const BoxRegion& region, 
-		const BoxPrintGC& gc) const;
+		const PrintGC& gc) const;
 
     BoxSize corner() const       { return _box->corner(); }
     string str() const           { return _box->str(); }
