@@ -1,4 +1,4 @@
-// $Id: MakeMenu.h,v 1.25 1998/05/23 11:05:44 zeller Exp $
+// $Id: MakeMenu.h,v 1.28 1998/11/12 18:01:08 zeller Exp $
 // Simple interface to motif menus
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -61,11 +61,12 @@ const MMType MMTypeMask    = 31; // mask to find type
 
 typedef int MMAttr;
 
-const MMAttr MMHelp           =  32; // Mark as help button
-const MMAttr MMInsensitive    =  64; // Make item insensitive
-const MMAttr MMUnmanaged      = 128; // Make item unmanaged
-const MMAttr MMUnmanagedLabel = 256; // Don't manage label (in panels)
-const MMAttr MMIgnore         = 512; // Don't create item
+const MMAttr MMHelp           =   32; // Mark as help button
+const MMAttr MMInsensitive    =   64; // Make item insensitive
+const MMAttr MMUnmanaged      =  128; // Make item unmanaged
+const MMAttr MMUnmanagedLabel =  256; // Don't manage label (in panels)
+const MMAttr MMIgnore         =  512; // Don't create item
+const MMAttr MMVertical       = 1024; // Make panel vertical
 const MMAttr MMAttrMask       = ~MMTypeMask;
 
 
@@ -73,7 +74,7 @@ const MMAttr MMAttrMask       = ~MMTypeMask;
 // Description data structure
 
 struct MMDesc {
-    String name;		 // Widget name
+    const char *name;		 // Widget name
     MMType type;		 // Widget type
     XtCallbackRec callback;	 // Associated callback
     MMDesc *items;		 // Submenus (NULL if none)
@@ -125,19 +126,22 @@ Widget MMcreatePushMenu          (Widget parent, String name, MMDesc items[],
 void MMadjustPanel(MMDesc items[], Dimension space = 15);
 
 // Add callbacks
-void MMaddCallbacks(MMDesc items[], XtPointer default_closure = 0);
-void MMaddHelpCallback(MMDesc items[], XtCallbackProc proc);
+void MMaddCallbacks(MMDesc items[],
+		    XtPointer default_closure = 0,
+		    int depth = -1);
+void MMaddHelpCallback(MMDesc items[], XtCallbackProc proc, int depth = -1);
 
 // Apply PROC on all ITEMS
-void MMonItems(MMDesc items[], MMItemProc proc, XtPointer closure = 0);
+void MMonItems(MMDesc items[], MMItemProc proc, XtPointer closure = 0,
+	       int depth = -1);
 
 // Add ITEMS to SHELL.  If IGNORE_SEPS is set, all separators are ignored.
 void MMaddItems(Widget shell, MMDesc items[], bool ignore_seps = false);
 
 // Conveniences
-#define MMNoCB { NULL }
-#define MMEnd  { NULL }
-#define MMSep  { "separator", MMSeparator }
+#define MMNoCB { 0, 0 }
+#define MMEnd  { 0, MMPush, MMNoCB, 0, 0, 0, 0 }
+#define MMSep  { "separator", MMSeparator, MMNoCB, 0, 0, 0, 0 }
 
 // New resources
 #define XtNpushMenuPopupTime  "pushMenuPopupTime"
