@@ -1,4 +1,4 @@
-// $Id: SourceView.h,v 1.143 1998/10/25 21:58:21 zeller Exp $
+// $Id: SourceView.h,v 1.143.4.1 1998/12/10 16:32:53 zeller Exp $
 // View the Source.
 
 // Copyright (C) 1995-1997 Technische Universitaet Braunschweig, Germany.
@@ -838,7 +838,7 @@ public:
     static string pwd() { return current_pwd; }
 
     // Return current class path
-    static string class_path() { return current_class_path; }
+    static string class_path();
 
     // Return current source file name
     static string name_of_source() { return current_source_name(); }
