@@ -1,4 +1,4 @@
-// $Id: StringBox.h,v 1.11 1998/03/25 12:44:24 zeller Exp $
+// $Id: StringBox.h,v 1.12 1998/10/04 11:05:17 zeller Exp $
 // A String Box contains a string
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -112,7 +112,7 @@ public:
 
     void _print(ostream& os, 
 		const BoxRegion& region, 
-		const BoxPrintGC& gc) const;
+		const PrintGC& gc) const;
 
     // Resources
     const XFontStruct *font() const { return _font; }
