@@ -1,4 +1,4 @@
-// $Id: mydialogs.h,v 1.18 1998/04/29 17:44:51 zeller Exp $
+// $Id: mydialogs.h,v 1.20 1998/11/23 17:43:47 zeller Exp $
 // Create dialogs to select display expressions
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -27,7 +27,7 @@
 // or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 //-----------------------------------------------------------------------------
-// Erzeugung von Motif-Dialogen zur Auswahl von Display-Ausdruecken
+// Create dialogs to select display expressions
 //-----------------------------------------------------------------------------
 
 #ifndef _DDD_mydialogs_h
@@ -51,8 +51,8 @@
 Widget createTopLevelSelectionDialog(Widget parent, String name,
 				     ArgList args, Cardinal num_args);
 
-// Get the display numbers
-void getDisplayNumbers(Widget selectionList, IntArray& arr);
+// Get the item numbers
+void getItemNumbers(Widget selectionList, IntArray& arr);
 
 
 // Set the elements of the display selection list
