@@ -1,4 +1,4 @@
-# $Id: yacctoC.h,v 1.6 1997/04/25 06:41:19 zeller Exp $
+# $Id: yacctoC.h,v 1.7 1998/03/25 12:46:57 zeller Exp $
 # Adapt BISON/YACC header output for C++ usage
 
 # Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -21,13 +21,15 @@
 # If not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 # 
-# ICE is the incremental configuration engine.
-# Contact ice@ips.cs.tu-bs.de for details.
+# ICE is the incremental configuration environment.
+# For details, see the ICE World-Wide-Web page, 
+# `http://www.cs.tu-bs.de/softech/ice/',
+# or send a mail to the ICE developers <ice@ips.cs.tu-bs.de>.
 
 # Declare functions
 1i\
 // This file was modified for -*- C++ -*-\
-// using $RCSfile: yacctoC.h,v $ $Revision: 1.6 $\
+// using $RCSfile: yacctoC.h,v $ $Revision: 1.7 $\
 
 # Make YYSTYPE a struct such that we can store class objects
 # (use anonymous unions to save space!)
